@@ -8,8 +8,13 @@ import redis
 import wget
 
 
-def checkDatasetLocalRequirements(benchmark_config, redis_dbdir, dirname=None, datasets_localtemp_dir="./datasets",
-                                  dbconfig_keyname="dbconfig"):
+def check_dataset_local_requirements(
+    benchmark_config,
+    redis_dbdir,
+    dirname=None,
+    datasets_localtemp_dir="./datasets",
+    dbconfig_keyname="dbconfig",
+):
     dataset = None
     full_path = None
     tmp_path = None
@@ -18,42 +23,54 @@ def checkDatasetLocalRequirements(benchmark_config, redis_dbdir, dirname=None, d
             if "dataset" in k:
                 dataset = k["dataset"]
         if dataset is not None:
-            if dataset.startswith("http"):
-                if not os.path.isdir(datasets_localtemp_dir):
-                    os.mkdir(datasets_localtemp_dir)
-                filename = dataset.split("/")[-1]
-                full_path = '{}/{}'.format(datasets_localtemp_dir, filename)
-                if not os.path.exists(full_path):
-                    logging.info(
-                        "Retrieving remote file from {} to {}. Using the dir {} as a cache for next time.".format(
-                            dataset, full_path, datasets_localtemp_dir))
-                    wget.download(dataset, full_path)
-                else:
-                    logging.info(
-                        "Reusing cached remote file (located at {} ).".format(
-                            full_path))
-            else:
-                full_path = dataset
-                if dirname is not None:
-                    full_path = "{}/{}".format(dirname, full_path)
-                logging.info("Copying rdb from {} to {}/dump.rdb".format(full_path, redis_dbdir))
+            full_path = check_if_needs_remote_fetch(
+                dataset, datasets_localtemp_dir, dirname
+            )
             tmp_path = "{}/dump.rdb".format(redis_dbdir)
+            logging.info(
+                "Copying rdb from {} to {}/dump.rdb".format(full_path, redis_dbdir)
+            )
             copyfile(full_path, tmp_path)
     return dataset, full_path, tmp_path
 
 
-def waitForConn(conn, retries=20, command="PING", shouldBe=True):
+def check_if_needs_remote_fetch(property, localtemp_dir, dirname, full_path=None):
+    if property.startswith("http"):
+        if not os.path.isdir(localtemp_dir):
+            os.mkdir(localtemp_dir)
+        if full_path is None:
+            filename = property.split("/")[-1]
+            full_path = "{}/{}".format(localtemp_dir, filename)
+        if not os.path.exists(full_path):
+            logging.info(
+                "Retrieving remote file from {} to {}. Using the dir {} as a cache for next time.".format(
+                    property, full_path, localtemp_dir
+                )
+            )
+            wget.download(property, full_path)
+        else:
+            logging.info(
+                "Reusing cached remote file (located at {} ).".format(full_path)
+            )
+    else:
+        full_path = property
+        if dirname is not None:
+            full_path = "{}/{}".format(dirname, full_path)
+
+    return full_path
+
+
+def wait_for_conn(conn, retries=20, command="PING", should_be=True):
     """Wait until a given Redis connection is ready"""
     result = False
-    err1 = ""
     while retries > 0 and result is False:
         try:
-            if conn.execute_command(command) == shouldBe:
+            if conn.execute_command(command) == should_be:
                 result = True
         except redis.exceptions.BusyLoadingError:
             time.sleep(0.1)  # give extra 100msec in case of RDB loading
         except redis.ConnectionError as err:
-            err1 = str(err)
+            str(err)
         except redis.ResponseError as err:
             err1 = str(err)
             if not err1.startswith("DENIED"):
@@ -64,12 +81,12 @@ def waitForConn(conn, retries=20, command="PING", shouldBe=True):
     return result
 
 
-def spinUpLocalRedis(
-        dbdir,
-        port,
-        local_module_file,
+def spin_up_local_redis(
+    dbdir,
+    port,
+    local_module_file,
 ):
-    command = generateStandaloneRedisServerArgs(dbdir, local_module_file, port)
+    command = generate_standalone_redis_server_args(dbdir, local_module_file, port)
 
     logging.info(
         "Running local redis-server with the following args: {}".format(
@@ -77,13 +94,13 @@ def spinUpLocalRedis(
         )
     )
     redis_process = subprocess.Popen(command)
-    result = waitForConn(redis.StrictRedis())
+    result = wait_for_conn(redis.StrictRedis(port=port))
     if result is True:
         logging.info("Redis available")
     return redis_process
 
 
-def generateStandaloneRedisServerArgs(dbdir, local_module_file, port):
+def generate_standalone_redis_server_args(dbdir, local_module_file, port):
     # start redis-server
     command = [
         "redis-server",
@@ -92,15 +109,19 @@ def generateStandaloneRedisServerArgs(dbdir, local_module_file, port):
         "--port",
         "{}".format(port),
         "--dir",
-        dbdir]
+        dbdir,
+    ]
     if local_module_file is not None:
-        command.extend(["--loadmodule",
-                        os.path.abspath(local_module_file),
-                        ])
+        command.extend(
+            [
+                "--loadmodule",
+                os.path.abspath(local_module_file),
+            ]
+        )
     return command
 
 
-def isProcessAlive(process):
+def is_process_alive(process):
     if not process:
         return False
     # Check if child process has terminated. Set and return returncode
@@ -110,10 +131,10 @@ def isProcessAlive(process):
     return False
 
 
-def getLocalRunFullFilename(
-        start_time_str,
-        github_branch,
-        test_name,
+def get_local_run_full_filename(
+    start_time_str,
+    github_branch,
+    test_name,
 ):
     benchmark_output_filename = (
         "{start_time_str}-{github_branch}-{test_name}.json".format(
