@@ -9,13 +9,13 @@ import git
 import paramiko
 import pysftp
 import redis
-import redistimeseries.client as Client
+import redistimeseries.client as client
 from git import Repo
 from jsonpath_ng import parse
 from python_terraform import Terraform
 from tqdm import tqdm
 
-from redisbench_admin.utils.local import checkDatasetLocalRequirements
+from redisbench_admin.utils.local import check_dataset_local_requirements
 
 
 def get_git_root(path):
@@ -24,16 +24,15 @@ def get_git_root(path):
     return git_root
 
 
-def viewBarSimple(a, b):
+def view_bar_simple(a, b):
     res = a / int(b) * 100
-    sys.stdout.write("\r    Complete precent: %.2f %%" % (res))
+    sys.stdout.write("\r    Complete precent: %.2f %%" % res)
     sys.stdout.flush()
 
 
-def copyFileToRemoteSetup(
-        server_public_ip, username, private_key, local_file, remote_file, dirname=None
+def copy_file_to_remote_setup(
+    server_public_ip, username, private_key, local_file, remote_file, dirname=None
 ):
-    res = False
     full_local_path = local_file
     if dirname is not None:
         full_local_path = "{}/{}".format(dirname, local_file)
@@ -41,32 +40,39 @@ def copyFileToRemoteSetup(
         "Copying local file {} to remote server {}".format(full_local_path, remote_file)
     )
     logging.info(
-        "Checking if local file {} exists: {}.".format(full_local_path, os.path.exists(full_local_path))
+        "Checking if local file {} exists: {}.".format(
+            full_local_path, os.path.exists(full_local_path)
+        )
     )
     if os.path.exists(full_local_path):
         cnopts = pysftp.CnOpts()
         cnopts.hostkeys = None
         srv = pysftp.Connection(
-            host=server_public_ip, username=username, private_key=private_key, cnopts=cnopts
+            host=server_public_ip,
+            username=username,
+            private_key=private_key,
+            cnopts=cnopts,
         )
-        srv.put(full_local_path, remote_file, callback=viewBarSimple)
+        srv.put(full_local_path, remote_file, callback=view_bar_simple)
         srv.close()
-        logging.info("Finished Copying file {} to remote server {} ".format(
-            full_local_path, remote_file
-        ))
+        logging.info(
+            "Finished Copying file {} to remote server {} ".format(
+                full_local_path, remote_file
+            )
+        )
         res = True
     else:
         logging.error(
             "Local file {} does not exists. aborting...".format(full_local_path)
         )
         raise Exception(
-            "Local file {} does not exists. aborting...".format(full_local_path))
-        res = False
+            "Local file {} does not exists. aborting...".format(full_local_path)
+        )
     return res
 
 
-def getFileFromRemoteSetup(
-        server_public_ip, username, private_key, local_file, remote_file
+def fetch_file_from_remote_setup(
+    server_public_ip, username, private_key, local_file, remote_file
 ):
     logging.info(
         "Retrieving remote file {} from remote server {} ".format(
@@ -78,14 +84,16 @@ def getFileFromRemoteSetup(
     srv = pysftp.Connection(
         host=server_public_ip, username=username, private_key=private_key, cnopts=cnopts
     )
-    srv.get(remote_file, local_file, callback=viewBarSimple)
+    srv.get(remote_file, local_file, callback=view_bar_simple)
     srv.close()
-    logging.info("Finished retrieving remote file {} from remote server {} ".format(
-        remote_file, server_public_ip
-    ))
+    logging.info(
+        "Finished retrieving remote file {} from remote server {} ".format(
+            remote_file, server_public_ip
+        )
+    )
 
 
-def executeRemoteCommands(server_public_ip, username, private_key, commands):
+def execute_remote_commands(server_public_ip, username, private_key, commands):
     res = []
     k = paramiko.RSAKey.from_private_key_file(private_key)
     c = paramiko.SSHClient()
@@ -104,14 +112,25 @@ def executeRemoteCommands(server_public_ip, username, private_key, commands):
     return res
 
 
-def checkDatasetRemoteRequirements(
-        benchmark_config, server_public_ip, username, private_key, remote_dataset_file, dirname
+def check_dataset_remote_requirements(
+    benchmark_config,
+    server_public_ip,
+    username,
+    private_key,
+    remote_dataset_file,
+    dirname,
 ):
     res = True
-    dataset, fullpath, tmppath = checkDatasetLocalRequirements(benchmark_config, ".", dirname)
+    dataset, fullpath, tmppath = check_dataset_local_requirements(
+        benchmark_config, ".", dirname
+    )
     if dataset is not None:
-        logging.info('Detected dataset config. Will copy file to remote setup... "{}"'.format(dataset))
-        res = copyFileToRemoteSetup(
+        logging.info(
+            'Detected dataset config. Will copy file to remote setup... "{}"'.format(
+                dataset
+            )
+        )
+        res = copy_file_to_remote_setup(
             server_public_ip,
             username,
             private_key,
@@ -122,33 +141,33 @@ def checkDatasetRemoteRequirements(
     return res
 
 
-def setupRemoteEnviroment(
-        tf: Terraform,
-        tf_github_sha,
-        tf_github_actor,
-        tf_setup_name,
-        tf_github_org,
-        tf_github_repo,
-        tf_triggering_env,
+def setup_remote_environment(
+    tf: Terraform,
+    tf_github_sha,
+    tf_github_actor,
+    tf_setup_name,
+    tf_github_org,
+    tf_github_repo,
+    tf_triggering_env,
 ):
     # key    = "benchmarks/infrastructure/tf-oss-redisgraph-standalone-r5.tfstate"
-    return_code, stdout, stderr = tf.init(
+    _, _, _ = tf.init(
         capture_output=True,
         backend_config={
             "key": "benchmarks/infrastructure/{}.tfstate".format(tf_setup_name)
         },
     )
-    return_code, stdout, stderr = tf.refresh()
+    _, _, _ = tf.refresh()
     tf_output = tf.output()
-    server_private_ip = tf_output["server_private_ip"]["value"][0]
-    server_public_ip = tf_output["server_public_ip"]["value"][0]
-    client_private_ip = tf_output["client_private_ip"]["value"][0]
-    client_public_ip = tf_output["client_public_ip"]["value"][0]
+    server_private_ip = tf_output_or_none(tf_output, "server_private_ip")
+    server_public_ip = tf_output_or_none(tf_output, "server_public_ip")
+    client_private_ip = tf_output_or_none(tf_output, "client_private_ip")
+    client_public_ip = tf_output_or_none(tf_output, "client_public_ip")
     if (
-            server_private_ip is not None
-            or server_public_ip is not None
-            or client_private_ip is not None
-            or client_public_ip is not None
+        server_private_ip is not None
+        or server_public_ip is not None
+        or client_private_ip is not None
+        or client_public_ip is not None
     ):
         logging.warning("Destroying previous setup")
         tf.destroy()
@@ -165,6 +184,10 @@ def setupRemoteEnviroment(
             "triggering_env": tf_triggering_env,
         },
     )
+    return retrieve_tf_connection_vars(return_code, tf)
+
+
+def retrieve_tf_connection_vars(return_code, tf):
     tf_output = tf.output()
     server_private_ip = tf_output["server_private_ip"]["value"][0]
     server_public_ip = tf_output["server_public_ip"]["value"][0]
@@ -183,7 +206,16 @@ def setupRemoteEnviroment(
     )
 
 
-def extract_git_vars(path=get_git_root("."), github_url=None):
+def tf_output_or_none(tf_output, output_prop):
+    res = None
+    if output_prop in tf_output:
+        res = tf_output[output_prop]["value"][0]
+    return res
+
+
+def extract_git_vars(path=None, github_url=None):
+    if path is None:
+        path = get_git_root(".")
     github_repo = Repo(path)
     if github_url is None:
         github_url = github_repo.remotes[0].config_reader.get("url")
@@ -193,7 +225,7 @@ def extract_git_vars(path=get_git_root("."), github_url=None):
         github_org_name = github_url.split("/")[-2]
         github_repo_name = github_url.split("/")[-1].split(".")[0]
     else:
-        github_url = github_url.replace('.git', '')
+        github_url = github_url.replace(".git", "")
         github_org_name = github_url.split(":")[1].split("/")[0]
         github_repo_name = github_url.split(":")[1].split("/")[1]
     github_sha = github_repo.head.object.hexsha
@@ -202,20 +234,35 @@ def extract_git_vars(path=get_git_root("."), github_url=None):
     try:
         github_branch = github_repo.active_branch
     except TypeError as e:
-        logging.warning("Unable to detected github_branch. caught the following error: {}".format(e.__str__()))
+        logging.warning(
+            "Unable to detected github_branch. caught the following error: {}".format(
+                e.__str__()
+            )
+        )
         github_branch_detached = True
 
     github_actor = None
     try:
         github_actor = github_repo.config_reader().get_value("user", "name")
     except configparser.NoSectionError as e:
-        logging.warning("Unable to detected github_actor. caught the following error: {}".format(e.__str__()))
+        logging.warning(
+            "Unable to detected github_actor. caught the following error: {}".format(
+                e.__str__()
+            )
+        )
         github_branch_detached = True
-    return github_org_name, github_repo_name, github_sha, github_actor, github_branch, github_branch_detached
+    return (
+        github_org_name,
+        github_repo_name,
+        github_sha,
+        github_actor,
+        github_branch,
+        github_branch_detached,
+    )
 
 
-def validateResultExpectations(
-        benchmark_config, results_dict, result, expectations_key="kpis"
+def validate_result_expectations(
+    benchmark_config, results_dict, result, expectations_key="kpis"
 ):
     for expectation in benchmark_config[expectations_key]:
         for comparison_mode, rules in expectation.items():
@@ -287,25 +334,25 @@ def validateResultExpectations(
 
 
 def upload_artifacts_to_s3(
-        artifacts, s3_bucket_name, s3_bucket_path, acl="public-read"
+    artifacts, s3_bucket_name, s3_bucket_path, acl="public-read"
 ):
     logging.info("Uploading results to s3")
     s3 = boto3.resource("s3")
     bucket = s3.Bucket(s3_bucket_name)
     progress = tqdm(unit="files", total=len(artifacts))
-    for input in artifacts:
+    for artifact in artifacts:
         object_key = "{bucket_path}{filename}".format(
-            bucket_path=s3_bucket_path, filename=input
+            bucket_path=s3_bucket_path, filename=artifact
         )
-        bucket.upload_file(input, object_key)
+        bucket.upload_file(artifact, object_key)
         object_acl = s3.ObjectAcl(s3_bucket_name, object_key)
-        response = object_acl.put(ACL=acl)
+        object_acl.put(ACL=acl)
         progress.update()
     progress.close()
 
 
-def checkAndFixPemStr(EC2_PRIVATE_PEM):
-    pem_str = EC2_PRIVATE_PEM.replace("-----BEGIN RSA PRIVATE KEY-----", "")
+def check_and_fix_pem_str(ec2_private_pem: str):
+    pem_str = ec2_private_pem.replace("-----BEGIN RSA PRIVATE KEY-----", "")
     pem_str = pem_str.replace("-----END RSA PRIVATE KEY-----", "")
     pem_str = pem_str.replace(" ", "\n")
     pem_str = "-----BEGIN RSA PRIVATE KEY-----\n" + pem_str
@@ -316,40 +363,43 @@ def checkAndFixPemStr(EC2_PRIVATE_PEM):
 
 
 def get_run_full_filename(
-        start_time_str,
-        deployment_type,
-        github_org,
-        github_repo,
-        github_branch,
-        test_name,
-        github_sha,
+    start_time_str,
+    deployment_type,
+    github_org,
+    github_repo,
+    github_branch,
+    test_name,
+    github_sha,
 ):
-    benchmark_output_filename = "{start_time_str}-{github_org}-{github_repo}-{github_branch}-{test_name}-{deployment_type}-{github_sha}.json".format(
-        start_time_str=start_time_str,
-        github_org=github_org,
-        github_repo=github_repo,
-        github_branch=github_branch,
-        test_name=test_name,
-        deployment_type=deployment_type,
-        github_sha=github_sha,
+    benchmark_output_filename = (
+        "{start_time_str}-{github_org}-{github_repo}-{github_branch}"
+        "-{test_name}-{deployment_type}-{github_sha}.json".format(
+            start_time_str=start_time_str,
+            github_org=github_org,
+            github_repo=github_repo,
+            github_branch=github_branch,
+            test_name=test_name,
+            deployment_type=deployment_type,
+            github_sha=github_sha,
+        )
     )
     return benchmark_output_filename
 
 
-def fetchRemoteSetupFromConfig(
-        remote_setup_config,
-        repo="https://github.com/RedisLabsModules/testing-infrastructure.git",
-        branch="master",
+def fetch_remote_setup_from_config(
+    remote_setup_config,
+    repo="https://github.com/RedisLabsModules/testing-infrastructure.git",
+    branch="master",
 ):
-    type = None
+    setup_type = None
     setup = None
     for remote_setup_property in remote_setup_config:
         if "type" in remote_setup_property:
-            type = remote_setup_property["type"]
+            setup_type = remote_setup_property["type"]
         if "setup" in remote_setup_property:
             setup = remote_setup_property["setup"]
     # fetch terraform folder
-    path = "/terraform/{}-{}".format(type, setup)
+    path = "/terraform/{}-{}".format(setup_type, setup)
     temporary_dir = tempfile.mkdtemp()
     logging.info(
         "Fetching infrastructure definition from git repo {}/{} (branch={})".format(
@@ -358,10 +408,10 @@ def fetchRemoteSetupFromConfig(
     )
     git.Repo.clone_from(repo, temporary_dir, branch=branch, depth=1)
     terraform_working_dir = temporary_dir + path
-    return terraform_working_dir, type
+    return terraform_working_dir, setup_type, setup
 
 
-def pushDataToRedisTimeSeries(rts: Client, branch_time_series_dict: dict):
+def push_data_to_redistimeseries(rts: client, branch_time_series_dict: dict):
     datapoint_errors = 0
     datapoint_inserts = 0
     for timeseries_name, time_series in branch_time_series_dict.items():
@@ -372,7 +422,7 @@ def pushDataToRedisTimeSeries(rts: Client, branch_time_series_dict: dict):
                 )
             )
             rts.create(timeseries_name, labels=time_series["labels"])
-        except redis.exceptions.ResponseError as e:
+        except redis.exceptions.ResponseError:
             logging.warning(
                 "Timeseries named {} already exists".format(timeseries_name)
             )
@@ -397,7 +447,7 @@ def pushDataToRedisTimeSeries(rts: Client, branch_time_series_dict: dict):
     return datapoint_errors, datapoint_inserts
 
 
-def extractRedisGraphVersion(results_dict: dict):
+def extract_redisgraph_version_from_resultdict(results_dict: dict):
     version = None
     if "DBSpecificConfigs" in results_dict:
         if "RedisGraphVersion" in results_dict["DBSpecificConfigs"]:
@@ -405,16 +455,16 @@ def extractRedisGraphVersion(results_dict: dict):
     return version
 
 
-def extractPerVersionTimeSeriesFromResults(
-        datapoints_timestamp: int,
-        metrics: list,
-        results_dict: dict,
-        project_version: str,
-        tf_github_org: str,
-        tf_github_repo: str,
-        deployment_type: str,
-        test_name: str,
-        tf_triggering_env: str,
+def extract_perversion_timeseries_from_results(
+    datapoints_timestamp: int,
+    metrics: list,
+    results_dict: dict,
+    project_version: str,
+    tf_github_org: str,
+    tf_github_repo: str,
+    deployment_type: str,
+    test_name: str,
+    tf_triggering_env: str,
 ):
     branch_time_series_dict = {}
     for jsonpath in metrics:
@@ -432,14 +482,18 @@ def extractPerVersionTimeSeriesFromResults(
             "triggering_env": tf_triggering_env,
             "metric": metric_name,
         }
-        ts_name = "ci.benchmarks.redislabs/by.version/{triggering_env}/{github_org}/{github_repo}/{test_name}/{deployment_type}/{version}/{metric}".format(
-            version=project_version,
-            github_org=tf_github_org,
-            github_repo=tf_github_repo,
-            deployment_type=deployment_type,
-            test_name=test_name,
-            triggering_env=tf_triggering_env,
-            metric=metric_name,
+        ts_name = (
+            "ci.benchmarks.redislabs/by.version/"
+            "{triggering_env}/{github_org}/{github_repo}/"
+            "{test_name}/{deployment_type}/{version}/{metric}".format(
+                version=project_version,
+                github_org=tf_github_org,
+                github_repo=tf_github_repo,
+                deployment_type=deployment_type,
+                test_name=test_name,
+                triggering_env=tf_triggering_env,
+                metric=metric_name,
+            )
         )
 
         branch_time_series_dict[ts_name] = {
@@ -449,16 +503,16 @@ def extractPerVersionTimeSeriesFromResults(
     return True, branch_time_series_dict
 
 
-def extractPerBranchTimeSeriesFromResults(
-        datapoints_timestamp: int,
-        metrics: list,
-        results_dict: dict,
-        tf_github_branch: str,
-        tf_github_org: str,
-        tf_github_repo: str,
-        deployment_type: str,
-        test_name: str,
-        tf_triggering_env: str,
+def extract_perbranch_timeseries_from_results(
+    datapoints_timestamp: int,
+    metrics: list,
+    results_dict: dict,
+    tf_github_branch: str,
+    tf_github_org: str,
+    tf_github_repo: str,
+    deployment_type: str,
+    test_name: str,
+    tf_triggering_env: str,
 ):
     branch_time_series_dict = {}
     for jsonpath in metrics:
@@ -476,14 +530,18 @@ def extractPerBranchTimeSeriesFromResults(
             "triggering_env": tf_triggering_env,
             "metric": metric_name,
         }
-        ts_name = "ci.benchmarks.redislabs/by.branch/{triggering_env}/{github_org}/{github_repo}/{test_name}/{deployment_type}/{branch}/{metric}".format(
-            branch=str(tf_github_branch),
-            github_org=tf_github_org,
-            github_repo=tf_github_repo,
-            deployment_type=deployment_type,
-            test_name=test_name,
-            triggering_env=tf_triggering_env,
-            metric=metric_name,
+        ts_name = (
+            "ci.benchmarks.redislabs/by.branch/"
+            "{triggering_env}/{github_org}/{github_repo}/"
+            "{test_name}/{deployment_type}/{branch}/{metric}".format(
+                branch=str(tf_github_branch),
+                github_org=tf_github_org,
+                github_repo=tf_github_repo,
+                deployment_type=deployment_type,
+                test_name=test_name,
+                triggering_env=tf_triggering_env,
+                metric=metric_name,
+            )
         )
 
         branch_time_series_dict[ts_name] = {
